@@ -15,6 +15,11 @@
 // along with the snarkVM library. If not, see <https://www.gnu.org/licenses/>.
 
 #![allow(clippy::module_inception)]
+#![forbid(unsafe_code)]
+
+#[cfg(feature = "wasm")]
+#[macro_use]
+extern crate alloc;
 
 #[macro_use]
 extern crate thiserror;
@@ -25,9 +30,6 @@ pub mod macros;
 pub mod errors;
 pub use errors::*;
 
-pub mod global;
-pub use global::*;
-
 pub mod testnet1;
 
 pub mod testnet2;
@@ -36,5 +38,5 @@ pub mod traits;
 pub use traits::*;
 
 pub mod prelude {
-    pub use crate::{errors::*, global::*, traits::*};
+    pub use crate::{errors::*, traits::*};
 }
